@@ -37,6 +37,7 @@ at the top-level directory.
  * </pre>
  */
 
+#include <unistd.h>
 #include "slu_zdefs.h"
 
 char *GLOBAL_EQUED;
@@ -59,7 +60,7 @@ void zpsolve(int n,
     double *R = GLOBAL_R, *C = GLOBAL_C;
     superlu_options_t *options = GLOBAL_OPTIONS;
     mem_usage_t  *mem_usage = GLOBAL_MEM_USAGE;
-    int info;
+    int_t info;
     static DNformat X, Y;
     static SuperMatrix XX = {SLU_DN, SLU_Z, SLU_GE, 1, 1, &X};
     static SuperMatrix YY = {SLU_DN, SLU_Z, SLU_GE, 1, 1, &Y};
@@ -109,11 +110,12 @@ int main(int argc, char *argv[])
     GlobalLU_t	   Glu; /* facilitate multiple factorizations with 
                            SamePattern_SameRowPerm                  */
     doublecomplex   *a, *a_orig;
-    int      *asub, *xa, *asub_orig, *xa_orig;
+    int_t    *asub, *xa, *asub_orig, *xa_orig;
     int      *etree;
     int      *perm_c; /* column permutation vector */
     int      *perm_r; /* row permutations from partial pivoting */
-    int      nrhs, ldx, lwork, info, m, n, nnz;
+    int      nrhs, ldx, m, n;
+    int_t    lwork, info, nnz;
     doublecomplex   *rhsb, *rhsx, *xact;
     doublecomplex   *work = NULL;
     double   *R, *C;
@@ -212,7 +214,7 @@ int main(int argc, char *argv[])
                                 SLU_NC, SLU_Z, SLU_GE);
     Astore = A.Store;
     zfill_diag(n, Astore);
-    printf("Dimension %dx%d; # nonzeros %d\n", A.nrow, A.ncol, Astore->nnz);
+    printf("Dimension %dx%d; # nonzeros %d\n", (int)A.nrow, (int)A.ncol, (int)Astore->nnz);
     fflush(stdout);
 
     /* Make a copy of the original matrix. */
@@ -238,9 +240,9 @@ int main(int argc, char *argv[])
     zGenXtrue(n, nrhs, xact, ldx);
     zFillRHS(trans, nrhs, xact, ldx, &A, &B);
 
-    if ( !(etree = intMalloc(n)) ) ABORT("Malloc fails for etree[].");
-    if ( !(perm_r = intMalloc(m)) ) ABORT("Malloc fails for perm_r[].");
-    if ( !(perm_c = intMalloc(n)) ) ABORT("Malloc fails for perm_c[].");
+    if ( !(etree = int32Malloc(n)) ) ABORT("Malloc fails for etree[].");
+    if ( !(perm_r = int32Malloc(m)) ) ABORT("Malloc fails for perm_r[].");
+    if ( !(perm_c = int32Malloc(n)) ) ABORT("Malloc fails for perm_c[].");
     if ( !(R = (double *) SUPERLU_MALLOC(A.nrow * sizeof(double))) )
 	ABORT("SUPERLU_MALLOC fails for R[].");
     if ( !(C = (double *) SUPERLU_MALLOC(A.ncol * sizeof(double))) )
@@ -265,7 +267,7 @@ int main(int argc, char *argv[])
     if (!(b = doublecomplexMalloc(m))) ABORT("Malloc fails for b[].");
     for (i = 0; i < m; i++) b[i] = rhsb[i];
 
-    printf("zgsisx(): info %d, equed %c\n", info, equed[0]);
+    printf("zgsisx(): info %lld, equed %c\n", (long long)info, equed[0]);
     if (info > 0 || rcond < 1e-8 || rpg > 1e8)
 	printf("WARNING: This preconditioner might be unstable.\n");
 
@@ -275,16 +277,16 @@ int main(int argc, char *argv[])
 	if ( options.ConditionNumber == YES )
 	    printf("Recip. condition number = %e\n", rcond);
     } else if ( info > 0 && lwork == -1 ) {
-	printf("** Estimated memory: %d bytes\n", info - n);
+	printf("** Estimated memory: %lld bytes\n", (long long)info - n);
     }
 
     Lstore = (SCformat *) L.Store;
     Ustore = (NCformat *) U.Store;
-    printf("n(A) = %d, nnz(A) = %d\n", n, Astore->nnz);
-    printf("No of nonzeros in factor L = %d\n", Lstore->nnz);
-    printf("No of nonzeros in factor U = %d\n", Ustore->nnz);
-    printf("No of nonzeros in L+U = %d\n", Lstore->nnz + Ustore->nnz - n);
-    printf("Fill ratio: nnz(F)/nnz(A) = %.3f\n",
+    printf("n(A) = %d, nnz(A) = %lld\n", n, (long long)Astore->nnz);
+    printf("No of nonzeros in factor L = %lld\n", (long long)Lstore->nnz);
+    printf("No of nonzeros in factor U = %lld\n", (long long)Ustore->nnz);
+    printf("No of nonzeros in L+U = %lld\n", (long long)Lstore->nnz + Ustore->nnz - n);
+    printf("Fill ratio: nnz(F)/nnz(A) = %.1f\n",
 	    ((double)(Lstore->nnz) + (double)(Ustore->nnz) - (double)n)
 	    / (double)Astore->nnz);
     printf("L\\U MB %.3f\ttotal MB needed %.3f\n",
@@ -336,7 +338,8 @@ int main(int argc, char *argv[])
 	t = SuperLU_timer_() - t;
 
 	/* Output the result. */
-	nrmA = dznrm2_(&(Astore->nnz), (doublecomplex *)((DNformat *)A.Store)->nzval,
+	int nnz32 = Astore->nnz;
+	nrmA = dznrm2_(&nnz32, (doublecomplex *)((DNformat *)A.Store)->nzval,
 		&i_1);
 	nrmB = dznrm2_(&m, b, &i_1);
 	sp_zgemv("N", none, &AA, x, 1, one, b, 1); /* Original matrix */
