@@ -1,3 +1,4 @@
+
 /*! \file
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
@@ -18,6 +19,7 @@ at the top-level directory.
  * Last update: July 10, 2015
  *
  */
+#include <unistd.h>
 #include "slu_zdefs.h"
 
 int main(int argc, char *argv[])
@@ -45,13 +47,13 @@ int main(int argc, char *argv[])
     SCformat       *Lstore;
     GlobalLU_t 	   Glu;
     doublecomplex         *a, *a1;
-    int            *asub, *xa, *asub1, *xa1;
+    int_t          *asub, *xa, *asub1, *xa1;
     int            *perm_r; /* row permutations from partial pivoting */
     int            *perm_c; /* column permutation vector */
     int            *etree;
-    void           *work = NULL;
-    int            info, lwork, nrhs, ldx;
-    int            i, j, m, n, nnz;
+    void           *work;
+    int            m, n, nrhs, ldx;
+    int_t          i, j, info, lwork, nnz;
     doublecomplex         *rhsb, *rhsb1, *rhsx, *xact;
     double         *R, *C;
     double         *ferr, *berr;
@@ -114,7 +116,7 @@ int main(int argc, char *argv[])
     
     zCreate_CompCol_Matrix(&A, m, n, nnz, a, asub, xa, SLU_NC, SLU_Z, SLU_GE);
     Astore = A.Store;
-    printf("Dimension %dx%d; # nonzeros %d\n", A.nrow, A.ncol, Astore->nnz);
+    printf("Dimension %dx%d; # nonzeros %d\n", (int)A.nrow, (int)A.ncol, (int)Astore->nnz);
     
     if ( !(rhsb = doublecomplexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsb[].");
     if ( !(rhsb1 = doublecomplexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsb1[].");
@@ -128,9 +130,9 @@ int main(int argc, char *argv[])
     for (j = 0; j < nrhs; ++j)
         for (i = 0; i < m; ++i) rhsb1[i+j*m] = rhsb[i+j*m];
     
-    if ( !(perm_c = intMalloc(n)) ) ABORT("Malloc fails for perm_c[].");
-    if ( !(perm_r = intMalloc(m)) ) ABORT("Malloc fails for perm_r[].");
-    if ( !(etree = intMalloc(n)) ) ABORT("Malloc fails for etree[].");
+    if ( !(perm_c = int32Malloc(n)) ) ABORT("Malloc fails for perm_c[].");
+    if ( !(perm_r = int32Malloc(m)) ) ABORT("Malloc fails for perm_r[].");
+    if ( !(etree = int32Malloc(n)) ) ABORT("Malloc fails for etree[].");
     if ( !(R = (double *) SUPERLU_MALLOC(A.nrow * sizeof(double))) ) 
         ABORT("SUPERLU_MALLOC fails for R[].");
     if ( !(C = (double *) SUPERLU_MALLOC(A.ncol * sizeof(double))) )
@@ -150,7 +152,7 @@ int main(int argc, char *argv[])
            &L, &U, work, lwork, &B, &X, &rpg, &rcond, ferr, berr,
            &Glu, &mem_usage, &stat, &info);
 
-    printf("First system: zgssvx() returns info %d\n", info);
+    printf("First system: zgssvx() returns info %lld\n", (long long)info);
 
     if ( info == 0 || info == n+1 ) {
 
@@ -162,9 +164,9 @@ int main(int argc, char *argv[])
 	    printf("Recip. condition number = %e\n", rcond);
         Lstore = (SCformat *) L.Store;
         Ustore = (NCformat *) U.Store;
-	printf("No of nonzeros in factor L = %d\n", Lstore->nnz);
-    	printf("No of nonzeros in factor U = %d\n", Ustore->nnz);
-    	printf("No of nonzeros in L+U = %d\n", Lstore->nnz + Ustore->nnz - n);
+	printf("No of nonzeros in factor L = %lld\n", (long long) Lstore->nnz);
+    	printf("No of nonzeros in factor U = %lld\n", (long long) Ustore->nnz);
+    	printf("No of nonzeros in L+U = %lld\n", (long long) Lstore->nnz + Ustore->nnz - n);
     	printf("FILL ratio = %.1f\n", (float)(Lstore->nnz + Ustore->nnz - n)/nnz);
 
 	printf("L\\U MB %.3f\ttotal MB needed %.3f\n",
@@ -173,12 +175,12 @@ int main(int argc, char *argv[])
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
 	    for (i = 0; i < nrhs; ++i)
-	      printf("%8d%8d%16e%16e\n", i+1, stat.RefineSteps, ferr[i], berr[i]);
+	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
 
     } else if ( info > 0 && lwork == -1 ) {
-        printf("** Estimated memory: %d bytes\n", info - n);
+        printf("** Estimated memory: %lld bytes\n", (long long)info - n);
     }
 
     if ( options.PrintStat ) StatPrint(&stat);
@@ -201,7 +203,7 @@ int main(int argc, char *argv[])
            &L, &U, work, lwork, &B1, &X, &rpg, &rcond, ferr, berr,
            &Glu, &mem_usage, &stat, &info);
 
-    printf("\nSecond system: zgssvx() returns info %d\n", info);
+    printf("\nSecond system: zgssvx() returns info %lld\n", (long long)info);
 
     if ( info == 0 || info == n+1 ) {
 
@@ -213,20 +215,20 @@ int main(int argc, char *argv[])
 	    printf("Recip. condition number = %e\n", rcond);
         Lstore = (SCformat *) L.Store;
         Ustore = (NCformat *) U.Store;
-	printf("No of nonzeros in factor L = %d\n", Lstore->nnz);
-    	printf("No of nonzeros in factor U = %d\n", Ustore->nnz);
-    	printf("No of nonzeros in L+U = %d\n", Lstore->nnz + Ustore->nnz - n);
+	printf("No of nonzeros in factor L = %lld\n", (long long) Lstore->nnz);
+    	printf("No of nonzeros in factor U = %lld\n", (long long) Ustore->nnz);
+    	printf("No of nonzeros in L+U = %lld\n", (long long) Lstore->nnz + Ustore->nnz - n);
 	printf("L\\U MB %.3f\ttotal MB needed %.3f\n",
 	       mem_usage.for_lu/1e6, mem_usage.total_needed/1e6);
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
 	    for (i = 0; i < nrhs; ++i)
-	      printf("%8d%8d%16e%16e\n", i+1, stat.RefineSteps, ferr[i], berr[i]);
+	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
     } else if ( info > 0 && lwork == -1 ) {
-        printf("** Estimated memory: %d bytes\n", info - n);
+        printf("** Estimated memory: %lld bytes\n", (long long)info - n);
     }
 
     if ( options.PrintStat ) StatPrint(&stat);
