@@ -22,11 +22,11 @@ at the top-level directory.
 
 
 /* Internal prototypes */
-void  *dexpand (int *, MemType,int, int, GlobalLU_t *);
+void  *dexpand (int_t *, MemType, int_t, int, GlobalLU_t *);
 int   dLUWorkInit (int, int, int, int **, double **, GlobalLU_t *);
-void  copy_mem_double (int, void *, void *);
+void  copy_mem_double (int_t, void *, void *);
 void  dStackCompress (GlobalLU_t *);
-void  dSetupSpace (void *, int, GlobalLU_t *);
+void  dSetupSpace (void *, int_t, GlobalLU_t *);
 void  *duser_malloc (int, int, GlobalLU_t *);
 void  duser_free (int, int, GlobalLU_t *);
 
@@ -51,7 +51,7 @@ extern void    user_bcopy      (char *, char *, int);
  *    lwork = 0: use system malloc;
  *    lwork > 0: use user-supplied work[] space.
  */
-void dSetupSpace(void *work, int lwork, GlobalLU_t *Glu)
+void dSetupSpace(void *work, int_t lwork, GlobalLU_t *Glu)
 {
     if ( lwork == 0 ) {
 	Glu->MemModel = SYSTEM; /* malloc/free */
@@ -186,8 +186,8 @@ int ilu_dQuerySpace(SuperMatrix *L, SuperMatrix *U, mem_usage_t *mem_usage)
  *     memory allocation failure occurred.
  * </pre> 
  */
-int
-dLUMemInit(fact_t fact, void *work, int lwork, int m, int n, int annz,
+int_t
+dLUMemInit(fact_t fact, void *work, int_t lwork, int m, int n, int_t annz,
 	  int panel_size, double fill_ratio, SuperMatrix *L, SuperMatrix *U,
           GlobalLU_t *Glu, int **iwork, double **dwork)
 {
@@ -195,12 +195,12 @@ dLUMemInit(fact_t fact, void *work, int lwork, int m, int n, int annz,
     SCformat *Lstore;
     NCformat *Ustore;
     int      *xsup, *supno;
-    int      *lsub, *xlsub;
+    int_t    *lsub, *xlsub;
     double   *lusup;
-    int      *xlusup;
+    int_t    *xlusup;
     double   *ucol;
-    int      *usub, *xusub;
-    int      nzlmax, nzumax, nzlumax;
+    int_t    *usub, *xusub;
+    int_t    nzlmax, nzumax, nzlumax;
     
     iword     = sizeof(int);
     dword     = sizeof(double);
@@ -213,8 +213,8 @@ dLUMemInit(fact_t fact, void *work, int lwork, int m, int n, int annz,
     
     if ( fact != SamePattern_SameRowPerm ) {
 	/* Guess for L\U factors */
-	nzumax = nzlumax = fill_ratio * annz;
-	nzlmax = SUPERLU_MAX(1, fill_ratio/4.) * annz;
+	nzumax = nzlumax = nzlmax = fill_ratio * annz;
+	//nzlmax = SUPERLU_MAX(1, fill_ratio/4.) * annz;
 
 	if ( lwork == -1 ) {
 	    return ( GluIntArray(n) * iword + TempSpace(m, panel_size)
@@ -224,30 +224,30 @@ dLUMemInit(fact_t fact, void *work, int lwork, int m, int n, int annz,
 	}
 	
 #if ( PRNTlevel >= 1 )
-	printf("dLUMemInit() called: fill_ratio %.0f, nzlmax %ld, nzumax %ld\n", 
-	       fill_ratio, nzlmax, nzumax);
+	printf("dLUMemInit() called: fill_ratio %.0f, nzlmax %lld, nzumax %lld\n", 
+	       fill_ratio, (long long) nzlmax, (long long) nzumax);
 	fflush(stdout);
 #endif	
 	
 	/* Integer pointers for L\U factors */
 	if ( Glu->MemModel == SYSTEM ) {
-	    xsup   = intMalloc(n+1);
-	    supno  = intMalloc(n+1);
+	    xsup   = int32Malloc(n+1);
+	    supno  = int32Malloc(n+1);
 	    xlsub  = intMalloc(n+1);
 	    xlusup = intMalloc(n+1);
 	    xusub  = intMalloc(n+1);
 	} else {
 	    xsup   = (int *)duser_malloc((n+1) * iword, HEAD, Glu);
 	    supno  = (int *)duser_malloc((n+1) * iword, HEAD, Glu);
-	    xlsub  = (int *)duser_malloc((n+1) * iword, HEAD, Glu);
-	    xlusup = (int *)duser_malloc((n+1) * iword, HEAD, Glu);
-	    xusub  = (int *)duser_malloc((n+1) * iword, HEAD, Glu);
+	    xlsub  = duser_malloc((n+1) * iword, HEAD, Glu);
+	    xlusup = duser_malloc((n+1) * iword, HEAD, Glu);
+	    xusub  = duser_malloc((n+1) * iword, HEAD, Glu);
 	}
 
 	lusup = (double *) dexpand( &nzlumax, LUSUP, 0, 0, Glu );
 	ucol  = (double *) dexpand( &nzumax, UCOL, 0, 0, Glu );
-	lsub  = (int *)    dexpand( &nzlmax, LSUB, 0, 0, Glu );
-	usub  = (int *)    dexpand( &nzumax, USUB, 0, 1, Glu );
+	lsub  = (int_t *) dexpand( &nzlmax, LSUB, 0, 0, Glu );
+	usub  = (int_t *) dexpand( &nzumax, USUB, 0, 1, Glu );
 
 	while ( !lusup || !ucol || !lsub || !usub ) {
 	    if ( Glu->MemModel == SYSTEM ) {
@@ -268,13 +268,13 @@ dLUMemInit(fact_t fact, void *work, int lwork, int m, int n, int annz,
 	    }
 #if ( PRNTlevel >= 1)
 	    printf("dLUMemInit() reduce size: nzlmax %ld, nzumax %ld\n", 
-		   nzlmax, nzumax);
+		   (long) nzlmax, (long) nzumax);
 	    fflush(stdout);
 #endif
 	    lusup = (double *) dexpand( &nzlumax, LUSUP, 0, 0, Glu );
 	    ucol  = (double *) dexpand( &nzumax, UCOL, 0, 0, Glu );
-	    lsub  = (int *)    dexpand( &nzlmax, LSUB, 0, 0, Glu );
-	    usub  = (int *)    dexpand( &nzumax, USUB, 0, 1, Glu );
+	    lsub  = (int_t *) dexpand( &nzlmax, LSUB, 0, 0, Glu );
+	    usub  = (int_t *) dexpand( &nzumax, USUB, 0, 1, Glu );
 	}
 	
     } else {
@@ -344,12 +344,14 @@ dLUWorkInit(int m, int n, int panel_size, int **iworkptr,
     int    maxsuper = SUPERLU_MAX( sp_ienv(3), sp_ienv(7) ),
            rowblk   = sp_ienv(4);
 
-    isize = ( (2 * panel_size + 3 + NO_MARKER ) * m + n ) * sizeof(int);
+    /* xplore[m] and xprune[n] can be 64-bit; they are allocated separately */
+    //isize = ( (2 * panel_size + 3 + NO_MARKER ) * m + n ) * sizeof(int);
+    isize = ( (2 * panel_size + 2 + NO_MARKER ) * m ) * sizeof(int);
     dsize = (m * panel_size +
 	     NUM_TEMPV(m,panel_size,maxsuper,rowblk)) * sizeof(double);
     
     if ( Glu->MemModel == SYSTEM ) 
-	*iworkptr = (int *) intCalloc(isize/sizeof(int));
+	*iworkptr = (int *) int32Calloc(isize/sizeof(int));
     else
 	*iworkptr = (int *) duser_malloc(isize, TAIL, Glu);
     if ( ! *iworkptr ) {
@@ -366,7 +368,7 @@ dLUWorkInit(int m, int n, int panel_size, int **iworkptr,
 	    *dworkptr = (double*) DoubleAlign(*dworkptr);
 	    *dworkptr = (double*) ((double*)*dworkptr - 1);
 	    extra = (char*)old_ptr - (char*)*dworkptr;
-#ifdef DEBUG	    
+#if ( DEBUGlevel>=1 )
 	    printf("dLUWorkInit: not aligned, extra %d\n", extra);
 #endif	    
 	    Glu->stack.top2 -= extra;
@@ -422,19 +424,19 @@ void dLUWorkFree(int *iwork, double *dwork, GlobalLU_t *Glu)
  *               > 0 - number of bytes allocated when run out of space
  * </pre>
  */
-int
+int_t
 dLUMemXpand(int jcol,
-	   int next,          /* number of elements currently in the factors */
+	   int_t next,          /* number of elements currently in the factors */
 	   MemType mem_type,  /* which type of memory to expand  */
-	   int *maxlen,       /* modified - maximum length of a data structure */
+	   int_t *maxlen,       /* modified - maximum length of a data structure */
 	   GlobalLU_t *Glu    /* modified - global LU data structures */
 	   )
 {
     void   *new_mem;
     
-#ifdef DEBUG    
-    printf("dLUMemXpand(): jcol %d, next %d, maxlen %d, MemType %d\n",
-	   jcol, next, *maxlen, mem_type);
+#if ( DEBUGlevel>=1 ) 
+    printf("dLUMemXpand(): jcol %d, next %lld, maxlen %lld, MemType %d\n",
+	   jcol, (long long) next, (long long) *maxlen, mem_type);
 #endif    
 
     if (mem_type == USUB) 
@@ -443,9 +445,9 @@ dLUMemXpand(int jcol,
 	new_mem = dexpand(maxlen, mem_type, next, 0, Glu);
     
     if ( !new_mem ) {
-	int    nzlmax  = Glu->nzlmax;
-	int    nzumax  = Glu->nzumax;
-	int    nzlumax = Glu->nzlumax;
+	int_t    nzlmax  = Glu->nzlmax;
+	int_t    nzumax  = Glu->nzumax;
+	int_t    nzlumax = Glu->nzlumax;
     	fprintf(stderr, "Can't expand MemType %d: jcol %d\n", mem_type, jcol);
     	return (dmemory_usage(nzlmax, nzumax, nzlumax, Glu->n) + Glu->n);
     }
@@ -460,11 +462,11 @@ dLUMemXpand(int jcol,
 	Glu->nzumax = *maxlen;
 	break;
       case LSUB:
-	Glu->lsub   = (int *) new_mem;
+	Glu->lsub   = (int_t *) new_mem;
 	Glu->nzlmax = *maxlen;
 	break;
       case USUB:
-	Glu->usub   = (int *) new_mem;
+	Glu->usub   = (int_t *) new_mem;
 	Glu->nzumax = *maxlen;
 	break;
       default: break;
@@ -475,11 +477,10 @@ dLUMemXpand(int jcol,
 }
 
 
-
 void
-copy_mem_double(int howmany, void *old, void *new)
+copy_mem_double(int_t howmany, void *old, void *new)
 {
-    register int i;
+    register int_t i;
     double *dold = old;
     double *dnew = new;
     for (i = 0; i < howmany; i++) dnew[i] = dold[i];
@@ -489,9 +490,9 @@ copy_mem_double(int howmany, void *old, void *new)
  */
 void
 *dexpand (
-	 int *prev_len,   /* length used from previous call */
+	 int_t *prev_len,   /* length used from previous call */
 	 MemType type,    /* which part of the memory to expand */
-	 int len_to_copy, /* size of the memory to be copied to new store */
+	 int_t len_to_copy, /* size of the memory to be copied to new store */
 	 int keep_prev,   /* = 1: use prev_len;
 			     = 0: compute new_len to expand */
 	 GlobalLU_t *Glu  /* modified - global LU data structures */
@@ -500,7 +501,8 @@ void
     float    EXPAND = 1.5;
     float    alpha;
     void     *new_mem, *old_mem;
-    int      new_len, tries, lword, extra, bytes_to_copy;
+    int_t    new_len, bytes_to_copy;
+    int      tries, lword, extra;
     ExpHeader *expanders = Glu->expanders; /* Array of 4 types of memory */
 
     alpha = EXPAND;
@@ -512,7 +514,7 @@ void
 	new_len = alpha * *prev_len;
     }
     
-    if ( type == LSUB || type == USUB ) lword = sizeof(int);
+    if ( type == LSUB || type == USUB ) lword = sizeof(int_t);
     else lword = sizeof(double);
 
     if ( Glu->MemModel == SYSTEM ) {
@@ -546,7 +548,7 @@ void
 		old_mem = new_mem;
 		new_mem = (void *)DoubleAlign(new_mem);
 		extra = (char*)new_mem - (char*)old_mem;
-#ifdef DEBUG		
+#if ( DEBUGlevel>=1 )
 		printf("expand(): not aligned, extra %d\n", extra);
 #endif		
 		Glu->stack.top1 += extra;
@@ -612,10 +614,10 @@ void
 dStackCompress(GlobalLU_t *Glu)
 {
     register int iword, dword, ndim;
-    char    *last, *fragment;
-    int      *ifrom, *ito;
+    char     *last, *fragment;
+    int_t    *ifrom, *ito;
     double   *dfrom, *dto;
-    int      *xlsub, *lsub, *xusub, *usub, *xlusup;
+    int_t    *xlsub, *lsub, *xusub, *usub, *xlusup;
     double   *ucol, *lusup;
     
     iword = sizeof(int);
@@ -636,12 +638,12 @@ dStackCompress(GlobalLU_t *Glu)
     ucol = dto;
 
     ifrom = lsub;
-    ito = (int *) ((char*)ucol + xusub[ndim] * iword);
+    ito = (int_t *) ((char*)ucol + xusub[ndim] * iword);
     copy_mem_int(xlsub[ndim], ifrom, ito);
     lsub = ito;
     
     ifrom = usub;
-    ito = (int *) ((char*)lsub + xlsub[ndim] * iword);
+    ito = (int_t *) ((char*)lsub + xlsub[ndim] * iword);
     copy_mem_int(xusub[ndim], ifrom, ito);
     usub = ito;
     
@@ -654,8 +656,8 @@ dStackCompress(GlobalLU_t *Glu)
     Glu->lsub = lsub;
     Glu->usub = usub;
     
-#ifdef DEBUG
-    printf("dStackCompress: fragment %d\n", fragment);
+#if ( DEBUGlevel>=1 )
+    printf("dStackCompress: fragment %lld\n", (long long) fragment);
     /* for (last = 0; last < ndim; ++last)
 	print_lu_col("After compress:", last, 0);*/
 #endif    
@@ -665,30 +667,30 @@ dStackCompress(GlobalLU_t *Glu)
 /*! \brief Allocate storage for original matrix A
  */
 void
-dallocateA(int n, int nnz, double **a, int **asub, int **xa)
+dallocateA(int n, int_t nnz, double **a, int_t **asub, int_t **xa)
 {
     *a    = (double *) doubleMalloc(nnz);
-    *asub = (int *) intMalloc(nnz);
-    *xa   = (int *) intMalloc(n+1);
+    *asub = (int_t *) intMalloc(nnz);
+    *xa   = (int_t *) intMalloc(n+1);
 }
 
 
-double *doubleMalloc(int n)
+double *doubleMalloc(size_t n)
 {
     double *buf;
-    buf = (double *) SUPERLU_MALLOC((size_t)n * sizeof(double)); 
+    buf = (double *) SUPERLU_MALLOC(n * (size_t) sizeof(double)); 
     if ( !buf ) {
 	ABORT("SUPERLU_MALLOC failed for buf in doubleMalloc()\n");
     }
     return (buf);
 }
 
-double *doubleCalloc(int n)
+double *doubleCalloc(size_t n)
 {
     double *buf;
-    register int i;
+    register size_t i;
     double zero = 0.0;
-    buf = (double *) SUPERLU_MALLOC((size_t)n * sizeof(double));
+    buf = (double *) SUPERLU_MALLOC(n * (size_t) sizeof(double));
     if ( !buf ) {
 	ABORT("SUPERLU_MALLOC failed for buf in doubleCalloc()\n");
     }
@@ -697,15 +699,16 @@ double *doubleCalloc(int n)
 }
 
 
-int dmemory_usage(const int nzlmax, const int nzumax, 
-		  const int nzlumax, const int n)
+int_t dmemory_usage(const int_t nzlmax, const int_t nzumax,
+		  const int_t nzlumax, const int n)
 {
-    register int iword, dword;
+    register int iword, liword, dword;
 
     iword   = sizeof(int);
+    liword  = sizeof(int_t);
     dword   = sizeof(double);
     
     return (10 * n * iword +
-	    nzlmax * iword + nzumax * (iword + dword) + nzlumax * dword);
+	    nzlmax * liword + nzumax * (liword + dword) + nzlumax * dword);
 
 }
