@@ -87,17 +87,17 @@ dpanel_bmod (
     int          fsupc, nsupc, nsupr, nrow;
     int          krep, krep_ind;
     double       ukj, ukj1, ukj2;
-    int          luptr, luptr1, luptr2;
+    int_t        luptr, luptr1, luptr2;
     int          segsze;
     int          block_nrow;  /* no of rows in a block row */
-    register int lptr;	      /* Points to the row subscripts of a supernode */
+    int_t        lptr;	      /* Points to the row subscripts of a supernode */
     int          kfnz, irow, no_zeros; 
     register int isub, isub1, i;
     register int jj;	      /* Index through each column in the panel */
     int          *xsup, *supno;
-    int          *lsub, *xlsub;
+    int_t        *lsub, *xlsub;
     double       *lusup;
-    int          *xlusup;
+    int_t        *xlusup;
     int          *repfnz_col; /* repfnz[] for a column in the panel */
     double       *dense_col;  /* dense[] for a column in the panel */
     double       *tempv1;             /* Used in 1-D update */
@@ -455,5 +455,3 @@ dpanel_bmod (
 
 }
 
-
-
