@@ -56,7 +56,7 @@
    Parameter adjustments   
        Function Body */
     /* System generated locals */
-    integer i__1, i__2, i__3, i__4, i__5;
+    integer i__2, i__3;
     doublereal d__1, d__2;
     complex q__1, q__2, q__3;
     /* Builtin functions */
@@ -73,7 +73,6 @@
 #define ISEED(I) iseed[(I)-1]
 
 
-    i__1 = *n;
     for (iv = 1; iv <= *n; iv += 64) {
 /* Computing MIN */
 	i__2 = 64, i__3 = *n - iv + 1;
@@ -93,8 +92,6 @@
 	    i__2 = il;
 	    for (i = 1; i <= il; ++i) {
 		i__3 = iv + i - 1;
-		i__4 = (i << 1) - 2;
-		i__5 = (i << 1) - 1;
 		q__1.r = u[(i<<1)-2], q__1.i = u[(i<<1)-1];
 		X(iv+i-1).r = q__1.r, X(iv+i-1).i = q__1.i;
 /* L10: */
