@@ -59,7 +59,6 @@
     
        Function Body */
     /* System generated locals */
-    integer i__1, i__2, i__3;
     /* Local variables */
     static integer i, j;
 
@@ -72,11 +71,8 @@
    
           array to ALPHA. */
 
-	i__1 = *n;
 	for (j = 2; j <= *n; ++j) {
 /* Computing MIN */
-	    i__3 = j - 1;
-	    i__2 = min(i__3,*m);
 	    for (i = 1; i <= min(j-1,*m); ++i) {
 		A(i,j) = *alpha;
 /* L10: */
@@ -90,9 +86,7 @@
    
           array to ALPHA. */
 
-	i__1 = min(*m,*n);
 	for (j = 1; j <= min(*m,*n); ++j) {
-	    i__2 = *m;
 	    for (i = j + 1; i <= *m; ++i) {
 		A(i,j) = *alpha;
 /* L30: */
@@ -104,9 +98,7 @@
 
 /*        Set the leading m-by-n submatrix to ALPHA. */
 
-	i__1 = *n;
 	for (j = 1; j <= *n; ++j) {
-	    i__2 = *m;
 	    for (i = 1; i <= *m; ++i) {
 		A(i,j) = *alpha;
 /* L50: */
@@ -117,7 +109,6 @@
 
 /*     Set the first min(M,N) diagonal elements to BETA. */
 
-    i__1 = min(*m,*n);
     for (i = 1; i <= min(*m,*n); ++i) {
 	A(i,i) = *beta;
 /* L70: */
