@@ -63,15 +63,16 @@ int dgst01(int m, int n, SuperMatrix *A, SuperMatrix *L,
 
     /* Local variables */
     double zero = 0.0;
-    int i, j, k, arow, lptr,isub,  urow, superno, fsupc, u_part;
-    double utemp, comp_temp;
+    int i, j, k, arow, superno, fsupc, u_part;
+    int_t urow, lptr, isub;
+    double utemp;
     double anorm, tnorm, cnorm;
     double eps;
     double *work;
     SCformat *Lstore;
     NCformat *Astore, *Ustore;
     double *Aval, *Lval, *Uval;
-    int *colbeg, *colend;
+    int_t *colbeg, *colend;
 
     /* Function prototypes */
     extern double dlangs(char *, SuperMatrix *);
