@@ -63,15 +63,16 @@ int sgst01(int m, int n, SuperMatrix *A, SuperMatrix *L,
 
     /* Local variables */
     float zero = 0.0;
-    int i, j, k, arow, lptr,isub,  urow, superno, fsupc, u_part;
-    float utemp, comp_temp;
+    int i, j, k, arow, superno, fsupc, u_part;
+    int_t urow, lptr, isub;
+    float utemp;
     float anorm, tnorm, cnorm;
     float eps;
     float *work;
     SCformat *Lstore;
     NCformat *Astore, *Ustore;
     float *Aval, *Lval, *Uval;
-    int *colbeg, *colend;
+    int_t *colbeg, *colend;
 
     /* Function prototypes */
     extern float slangs(char *, SuperMatrix *);
