@@ -35,7 +35,7 @@ at the top-level directory.
 static void
 parse_command_line(int argc, char *argv[], char *matrix_type,
 		   int *n, int *w, int *relax, int *nrhs, int *maxsuper,
-		   int *rowblk, int *colblk, int *lwork, double *u, FILE **fp);
+		   int *rowblk, int *colblk, int_t *lwork, double *u, FILE **fp);
 
 int main(int argc, char *argv[])
 {
@@ -52,8 +52,8 @@ int main(int argc, char *argv[])
  * =====================================================================
  */
     doublecomplex         *a, *a_save;
-    int            *asub, *asub_save;
-    int            *xa, *xa_save;
+    int_t          *asub, *asub_save;
+    int_t          *xa, *xa_save;
     SuperMatrix  A, B, X, L, U;
     SuperMatrix  ASAV, AC;
     GlobalLU_t   Glu; /* Not needed on return. */
@@ -66,9 +66,10 @@ int main(int argc, char *argv[])
     double         *ferr, *berr;
     double         *rwork;
     doublecomplex	   *wwork;
-    void           *work = NULL;
-    int            info, lwork, nrhs, panel_size, relax;
-    int            m, n, nnz;
+    void           *work;
+    int            nrhs, panel_size, relax;
+    int            m, n, info1;
+    int_t          nnz, lwork, info;
     doublecomplex         *xact;
     doublecomplex         *rhsb, *solx, *bsav;
     int            ldb, ldx;
@@ -76,14 +77,14 @@ int main(int argc, char *argv[])
     int            i, j, k1;
     double         rowcnd, colcnd, amax;
     int            maxsuper, rowblk, colblk;
-    int            prefact, nofact, equil, iequed;
+    int            prefact, equil, iequed;
     int            nt, nrun, nfail, nerrs, imat, fimat, nimat;
     int            nfact, ifact, itran;
     int            kl, ku, mode, lda;
     int            zerot, izero, ioff;
     double         u;
     double         anorm, cndnum;
-    doublecomplex         *Afull = NULL;
+    doublecomplex         *Afull;
     double         result[NTESTS];
     superlu_options_t options;
     fact_t         fact;
@@ -116,7 +117,7 @@ int main(int argc, char *argv[])
                        int *, double *, double *, int *, int *,
                        char *, doublecomplex *, int *, doublecomplex *, int *);
     extern int sp_zconvert(int, int, doublecomplex *, int, int, int,
-	                   doublecomplex *a, int *, int *, int *);
+	                   doublecomplex *a, int_t *, int_t *, int_t *);
 
 
     /* Executable statements */
@@ -140,7 +141,7 @@ int main(int argc, char *argv[])
     if ( lwork > 0 ) {
 	work = SUPERLU_MALLOC(lwork);
 	if ( !work ) {
-	    fprintf(stderr, "expert: cannot allocate %d bytes\n", lwork);
+	    fprintf(stderr, "expert: cannot allocate %lld bytes\n", (long long) lwork);
 	    exit (-1);
 	}
     }
@@ -177,10 +178,10 @@ int main(int argc, char *argv[])
     zCreate_Dense_Matrix(&B, m, nrhs, rhsb, ldb, SLU_DN, SLU_Z, SLU_GE);
     zCreate_Dense_Matrix(&X, n, nrhs, solx, ldx, SLU_DN, SLU_Z, SLU_GE);
     xact = doublecomplexMalloc(n * nrhs);
-    etree   = intMalloc(n);
-    perm_r  = intMalloc(n);
-    perm_c  = intMalloc(n);
-    pc_save = intMalloc(n);
+    etree   = int32Malloc(n);
+    perm_r  = int32Malloc(n);
+    perm_c  = int32Malloc(n);
+    pc_save = int32Malloc(n);
     R       = (double *) SUPERLU_MALLOC(m*sizeof(double));
     C       = (double *) SUPERLU_MALLOC(n*sizeof(double));
     ferr    = (double *) SUPERLU_MALLOC(nrhs*sizeof(double));
@@ -214,10 +215,10 @@ int main(int argc, char *argv[])
 
 	    zlatms_slu(&n, &n, dist, iseed, sym, &rwork[0], &mode, &cndnum,
 		    &anorm, &kl, &ku, "No packing", Afull, &lda,
-		    &wwork[0], &info);
+		    &wwork[0], &info1);
 
-	    if ( info ) {
-		printf(FMT3, "ZLATMS", info, izero, n, nrhs, imat, nfail);
+	    if ( info1 ) {
+		printf(FMT3, "ZLATMS", info1, izero, n, nrhs, imat, nfail);
 		continue;
 	    }
 
@@ -273,7 +274,6 @@ int main(int argc, char *argv[])
 		    prefact   = ( options.Fact == FACTORED ||
 				  options.Fact == SamePattern_SameRowPerm );
                                 /* Need a first factor */
-		    nofact    = (options.Fact != FACTORED);  /* Not factored */
 
 		    /* Restore the matrix A. */
 		    zCopy_CompCol_Matrix(&ASAV, &A);
@@ -284,7 +284,7 @@ int main(int argc, char *argv[])
                         if ( equil || iequed ) {
 			    /* Compute row and column scale factors to
 			       equilibrate matrix A.    */
-			    zgsequ(&A, R, C, &rowcnd, &colcnd, &amax, &info);
+			    zgsequ(&A, R, C, &rowcnd, &colcnd, &amax, &info1);
 
 			    /* Force equilibration. */
 			    if ( !info && n > 0 ) {
@@ -320,11 +320,11 @@ int main(int argc, char *argv[])
                                &Glu, &stat, &info);
 
 			if ( info ) { 
-                            printf("** First factor: info %d, equed %c\n",
-				   info, *equed);
+                            printf("** First factor: info %lld, equed %c\n",
+				   (long long) info, *equed);
                             if ( lwork == -1 ) {
-                                printf("** Estimated memory: %d bytes\n",
-                                        info - n);
+                                printf("** Estimated memory: %lld bytes\n",
+                                        (long long) info - n);
                                 exit(0);
                             }
                         }
@@ -358,7 +358,7 @@ int main(int argc, char *argv[])
 			    
 			    if ( info && info != izero ) {
                                 printf(FMT3, "zgssv",
-				       info, izero, n, nrhs, imat, nfail);
+				       (int) info, izero, n, nrhs, imat, nfail);
 			    } else {
                                 /* Reconstruct matrix from factors and
 	                           compute residual. */
@@ -416,7 +416,7 @@ int main(int argc, char *argv[])
 
 			if ( info && info != izero ) {
 			    printf(FMT3, "zgssvx",
-				   info, izero, n, nrhs, imat, nfail);
+				   (int) info, izero, n, nrhs, imat, nfail);
                             if ( lwork == -1 ) {
                                 printf("** Estimated memory: %.0f bytes\n",
                                         mem_usage.total_needed);
@@ -528,7 +528,7 @@ int main(int argc, char *argv[])
 static void
 parse_command_line(int argc, char *argv[], char *matrix_type,
 		   int *n, int *w, int *relax, int *nrhs, int *maxsuper,
-		   int *rowblk, int *colblk, int *lwork, double *u, FILE **fp)
+		   int *rowblk, int *colblk, int_t *lwork, double *u, FILE **fp)
 {
     int c;
     extern char *optarg;
