@@ -63,15 +63,17 @@ int zgst01(int m, int n, SuperMatrix *A, SuperMatrix *L,
 
     /* Local variables */
     doublecomplex zero = {0.0, 0.0};
-    int i, j, k, arow, lptr,isub,  urow, superno, fsupc, u_part;
-    doublecomplex utemp, comp_temp;
+    int i, j, k, arow, superno, fsupc, u_part;
+    int_t urow, lptr, isub;
+    doublecomplex utemp;
+    doublecomplex comp_temp;
     double anorm, tnorm, cnorm;
     double eps;
     doublecomplex *work;
     SCformat *Lstore;
     NCformat *Astore, *Ustore;
     doublecomplex *Aval, *Lval, *Uval;
-    int *colbeg, *colend;
+    int_t *colbeg, *colend;
 
     /* Function prototypes */
     extern double zlangs(char *, SuperMatrix *);
